==> jugg-agile-middleware-redis-2.0-agile-redis-20250828.024637-30-sources.jar: com/jugg/agile/middleware/redis/adapter/jedis/pool/JedisClusterPool.java <==
package com.jugg.agile.middleware.redis.adapter.jedis.pool;

import com.jugg.agile.framework.core.util.JaShutdownHookUtil;
import com.jugg.agile.framework.core.util.JaStringUtil;
import com.jugg.agile.middleware.redis.adapter.jedis.JaJedisPoolConfig;
import com.jugg.agile.middleware.redis.config.JaRedisConfig;
import com.jugg.agile.middleware.redis.config.JaRedisPoolConfig;
import org.apache.commons.pool2.impl.GenericObjectPoolConfig;
import redis.clients.jedis.HostAndPort;
import redis.clients.jedis.JedisCluster;

import java.util.HashSet;
import java.util.Set;

/**
 * redis 集群模式
 *
 * @author chenjian
 * @since 2020年06月09日 17:21:04
 */
public class JedisClusterPool {

    private JedisClusterPool() {
    }

    private static final JedisCluster jedisCluster;

    static {
        JaRedisConfig config = JaRedisConfig.load();
        JaRedisPoolConfig pool = config.getPool();
        // 添加集群的服务节点Set集合
        // 添加节点
        String cluster = config.getCluster();
        if (JaStringUtil.isEmpty(cluster)) {
            throw new RuntimeException("redis cluster is null");
        }
        String[] clusterArray = cluster.split(",");
        Set<HostAndPort> hostAndPortsSet = new HashSet<>(clusterArray.length);
        for (String s : clusterArray) {
            if (JaStringUtil.isNotEmpty(s)) {
                String[] hostAndPort = s.split(":");
                hostAndPortsSet.add(new HostAndPort(hostAndPort[0], Integer.parseInt(hostAndPort[1])));
            }
        }

        GenericObjectPoolConfig poolConfig = JaJedisPoolConfig.create(pool);

        String password = config.getPassword();
        if (JaStringUtil.isEmpty(password)) {
            jedisCluster = new JedisCluster(hostAndPortsSet, poolConfig);
        } else {
            jedisCluster = new JedisCluster(hostAndPortsSet
                    , config.getConnectionTimeout()
                    , config.getSoTimeout()
                    , config.getMaxAttempts()
                    , password
                    , poolConfig);
        }
        JaShutdownHookUtil.add("JedisCluster", jedisCluster::shutdown);
    }

    /**
     * 获取jedis
     */
    public static JedisCluster get() {
        return jedisCluster;
    }
}

==> jugg-agile-middleware-redis-2.6.13.0-agile-redis-20250821.074026-3-sources.jar: com/jugg/agile/middleware/redis/adapter/jedis/pool/JedisClusterPool.java <==
package com.jugg.agile.middleware.redis.adapter.jedis.pool;

import com.jugg.agile.framework.core.util.JaShutdownHookUtil;
import com.jugg.agile.framework.core.util.JaStringUtil;
import com.jugg.agile.middleware.redis.adapter.jedis.JaJedisPoolConfig;
import com.jugg.agile.middleware.redis.config.JaRedisConfig;
import com.jugg.agile.middleware.redis.config.JaRedisPoolConfig;
import org.apache.commons.pool2.impl.GenericObjectPoolConfig;
import redis.clients.jedis.Connection;
import redis.clients.jedis.HostAndPort;
import redis.clients.jedis.JedisCluster;

import java.util.HashSet;
import java.util.Set;

/**
 * redis 集群模式
 *
 * @author chenjian
 * @since 2020年06月09日 17:21:04
 */
public class JedisClusterPool {

    private JedisClusterPool() {
    }

    private static final JedisCluster jedisCluster;

    static {
        JaRedisConfig config = JaRedisConfig.load();
        JaRedisPoolConfig pool = config.getPool();
        // 添加集群的服务节点Set集合
        // 添加节点
        String cluster = config.getCluster();
        if (JaStringUtil.isEmpty(cluster)) {
            throw new RuntimeException("redis cluster is null");
        }
        String[] clusterArray = cluster.split(",");
        Set<HostAndPort> hostAndPortsSet = new HashSet<>(clusterArray.length);
        for (String s : clusterArray) {
            if (JaStringUtil.isNotEmpty(s)) {
                String[] hostAndPort = s.split(":");
                hostAndPortsSet.add(new HostAndPort(hostAndPort[0], Integer.parseInt(hostAndPort[1])));
            }
        }

        GenericObjectPoolConfig<Connection> poolConfig = JaJedisPoolConfig.create(pool);

        String password = config.getPassword();
        if (JaStringUtil.isEmpty(password)) {
            jedisCluster = new JedisCluster(hostAndPortsSet, poolConfig);
        } else {
            jedisCluster = new JedisCluster(hostAndPortsSet
                    , config.getConnectionTimeout()
                    , config.getSoTimeout()
                    , config.getMaxAttempts()
                    , password
                    , poolConfig);
        }
        JaShutdownHookUtil.add("JedisCluster", jedisCluster::close);
    }

    /**
     * 获取jedis
     */
    public static JedisCluster get() {
        return jedisCluster;
    }
}
